pub fn detect_package_manager(dir: &Path) -> PackageManagerExpand description
Detects the package manager by checking for lock files in the given directory Priority: bun.lockb > pnpm-lock.yaml > yarn.lock > package-lock.json > npm (default)
pub fn detect_package_manager(dir: &Path) -> PackageManagerDetects the package manager by checking for lock files in the given directory Priority: bun.lockb > pnpm-lock.yaml > yarn.lock > package-lock.json > npm (default)